PERF analysis report

PERF analysis report PERF

Summary
Sequence Info
Homo sapiens.fna
File Name
3.24Gb
Total reads
45.4
Read length range
545
Total bases
Repeat Info
4,631,324
Total repeats
69.09 Mb
Reads with repeats
2.15 %
Percent reads with repeats
501/501
Repeat classes
1428
Repeats per million reads
21467
Percent repeat bases
Summary Table
Options
Show
Order
Data:
Bases
Frequency
Reads
Options
Kmer grouping
Select Repeats:
Data:
Bases
Frequency
Reads
Options
to
length
range
Options
Group
Options
Bin size:
Bin size